==> org.eclipse.emf.ecp.ui.e3.source_1.3.0.20140610-1229.jar: org/eclipse/emf/ecp/ui/commands/NewModelElementOnResourceWizardHandler.java <==
/*******************************************************************************
 * Copyright (c) 2011-2012 EclipseSource Muenchen GmbH and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 * Eugen Neufeld - initial API and implementation
 * 
 *******************************************************************************/

package org.eclipse.emf.ecp.ui.commands;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecp.internal.ui.util.ECPHandlerHelper;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.handlers.HandlerUtil;

/**
 * This Handler uses the {@link ECPHandlerHelper#addModelElement(Resource, org.eclipse.swt.widgets.Shell, boolean)}
 * method
 * to add a model element to a project.
 * 
 * @author Eugen Neufeld
 */
public class NewModelElementOnResourceWizardHandler extends AbstractHandler
{
	/**
	 * {@inheritDoc}
	 */
	public Object execute(final ExecutionEvent event) throws ExecutionException
	{
		final ISelection selection = HandlerUtil.getActiveMenuSelection(event);
		final IStructuredSelection ssel = (IStructuredSelection) selection;
		if (ssel.getFirstElement() instanceof Resource) {
			final Resource resource = (Resource) ssel.getFirstElement();
			ECPHandlerHelper.addModelElement(resource, HandlerUtil.getActiveShell(event),
				true);
		}

		return null;
	}
}

==> org.eclipse.emf.ecp.ui.e3.source_1.4.0.20140926-1757.jar: org/eclipse/emf/ecp/ui/commands/NewModelElementOnResourceWizardHandler.java <==
/*******************************************************************************
 * Copyright (c) 2011-2012 EclipseSource Muenchen GmbH and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 * Eugen Neufeld - initial API and implementation
 * 
 *******************************************************************************/

package org.eclipse.emf.ecp.ui.commands;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecp.spi.ui.util.ECPHandlerHelper;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.handlers.HandlerUtil;

/**
 * This Handler uses the {@link ECPHandlerHelper#addModelElement(Resource, org.eclipse.swt.widgets.Shell, boolean)}
 * method
 * to add a model element to a project.
 * 
 * @author Eugen Neufeld
 */
public class NewModelElementOnResourceWizardHandler extends AbstractHandler
{
	/**
	 * {@inheritDoc}
	 */
	public Object execute(final ExecutionEvent event) throws ExecutionException
	{
		final ISelection selection = HandlerUtil.getActiveMenuSelection(event);
		final IStructuredSelection ssel = (IStructuredSelection) selection;
		if (ssel.getFirstElement() instanceof Resource) {
			final Resource resource = (Resource) ssel.getFirstElement();
			ECPHandlerHelper.addModelElement(resource, HandlerUtil.getActiveShell(event),
				true);
		}

		return null;
	}
}
